/*
appendix.do

This file creates the tables for the appendix in Papageorge et. al (2019). 
Last updated: 10/04/2019.
	* Table A1: Test of Nonrandom Attrition
	* Table A2: Missing Outcomes
	* Table A3: Heterogeneity in Effects of HAART on Domestic Violence
	* Table A4: Health, Violence, and Drug Use: Marginal Effects of Women Who Did Not Die w/i 7.5 Years
	* Table A5: Normalized Differences
	* Table A6: Propensity Score (and Figure A2)
	* Table A7: Joint Estimation: Domestic Violence and Cocaine Use
	* Table A8: Joint Estimation: Domestic Violence and Heroin Use

Last updated: 10/07/2019. 
*/


#delimit; 

*** These are the tables that this file creates- can turn on or off; 
local TA1 1; 
local TA2 1; 
local TA3 1; 
local TA4 1; 
local TA5 1; 
local TA6 1; 
local TA7A8 1; 

***** Table A.1 Test of Nonrandom Attrition;
if `TA1'==1 {;
*** call data;
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear;

*** define controls ;
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/;

*** drop hiv negative & second cohort; 
drop if positive==0 | cohort!=1;


*** generate variables needed for analysis; 
** unique tag; 
bys wihsid: gen uniqcount = (_n==1);

** attrit ever; 
gen attrit = 0;
replace attrit = 1 if maxvis<33;


label var dvapreH "Violence pre-HAART";


*** just keep healthy and salient groups ;
keep if healthysamp==1 | targetsamp==1 ;


**** Attrit;
*** no controls ; 
logit attrit targetgrp if uniqcount==1;
est2vec TA1_attrition, replace vars(targetgrp ageatvis agesq agecube raceaa racehisp raceother dvapreH);

* r squared; 
gen r2_p = e(r2_p) if e(sample);
label var r2_p "Pseudo \$R^{2}\$";

gen r2 = .; 
label var r2 "\$R^{2}\$";

* mean ;
egen outcome = mean(attrit) if e(sample);
label var outcome "Mean";

estpost su outcome r2_p r2 if e(sample);
est store A;

*** with controls; 
logit attrit `control0' targetgrp if uniqcount==1;
est2vec TA1_attrition, name(col2) addto(TA1_attrition);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* mean ; 
ereplace outcome = mean(attrit) if e(sample);

estpost su outcome r2_p r2 if e(sample);
est store B; 

*** with controls & interaction; 
logit attrit `control0' targetgrp dvapreH if uniqcount==1;
est2vec TA1_attrition, name(col3) addto(TA1_attrition);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* mean; 
ereplace outcome = mean(attrit) if e(sample);

estpost su outcome r2_p r2 if e(sample);
est store C; 


**** Maximum # of visits; 
*** no controls; 
reg maxvis targetgrp if uniqcount==1;
est2vec TA1_attrition, name(col4) addto(TA1_attrition);

* r squared; 
replace r2_p = .; 
replace r2 = e(r2) if e(sample);

* mean; 
ereplace outcome = mean(maxvis) if e(sample);

estpost su outcome r2_p r2 if e(sample);
est store D; 


*** with controls; 
reg maxvis targetgrp `control0' if uniqcount==1;
est2vec TA1_attrition, name(col5) addto(TA1_attrition);

* r squared; 
replace r2 = e(r2) if e(sample);

* mean; 
ereplace outcome = mean(maxvis) if e(sample);

estpost su outcome r2_p r2 if e(sample);
est store E; 

*** with controls & interaction; 
reg maxvis targetgrp `control0' dvapreH if uniqcount==1;
est2vec TA1_attrition, name(col6) addto(TA1_attrition);

* r squared; 
replace r2 = e(r2) if e(sample);

* mean; 
ereplace outcome = mean(maxvis) if e(sample);

estpost su outcome r2_p r2 if e(sample);
est store F; 


***** Create the tables; 
est2texOWO TA1_attrition, collabels(1 2 3 4 5 6) mark(starb) label dots notabular path($tabledir/appendix) levels(90 95 99) fancy preserve replace;


esttab A B C D E F using "$tabledir/appendix/TA1_attritionstats.tex", replace label cells(mean(fmt(3)));

};


**** Table: Missing Outcomes (T-A2);
if `TA2'==1 {;
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;


keep if visit!=0 & visit!=88 & visit!=99 ; 
keep if cohort==1;
keep if positive==1; 

bys wihsid: gen nvals=_n==1; 

* drop if dv wasn't asked at all or if last visit was death follow up visit; 
local dva1miss 10,12,14,16,18,20,22,24,26,28,30,32,33; 
tab samp_full if inlist(visit,`dva1miss'); 

drop if inlist(visit,`dva1miss'); 
count; 
tab nvals; 

tab maxvisdeath if death==1 ; 
drop if alive==0; 
count;
tab nvals; 

* back to missing stuff; 
* drop if missing mincd4preH; 
keep if mincd4preH!=.; 
count;
tab nvals; 

* basics; 
count if HAARTavailable==.;
count if ageatvis==.;
count if race==.;
count if site==.;

keep if HAARTavailable!=. & ageatvis!=. & race!=. & site!=.;
count;  
tab nvals; 

* next pd outcomes: dvemployment, stimulant, and heroin use; 
foreach var in dva employ stimulantfull cocainefull heruse inc {; 
gen `var'1miss = `var'1==.;
}; 


gen lcd4m = lcd4==.; 
gen lcd4mt = lcd4m&targetgrp; 

* gen an imputed value for lcd4; 
gen lcd4imp = lcd4;

reg lcd4 raceaa racehisp raceother ageatvis agesq i.site targetgrp, cluster(wihsid); 
predict lcd4hat; 

replace lcd4imp = lcd4hat if lcd4==.;
label var lcd4imp "Log CD4"; 

gen lcd4t = targetgrp*lcd4imp;
label var lcd4t "Treatment $\times$ CD4"; 

*** violence; 
xi: reg dva1miss targetgrp lcd4imp lcd4t raceaa racehisp raceother ageatvis agesq i.site if site!=4 & site!=5,  cluster(wihsid) ; 
est2vec TA2_missingoutcome, replace vars(targetgrp lcd4imp lcd4t); 

* mean; 
egen outcome = mean(dva1miss) if e(sample);
label var outcome "Mean";

* r squared; 
gen r2 = e(r2) if e(sample);
label var r2 "\$R^{2}\$";

estpost su outcome r2 if e(sample);
est store A;

*** cocaine; 
reg cocainefull1miss targetgrp lcd4imp lcd4t raceaa racehisp raceother ageatvis agesq i.site,  cluster(wihsid);
est2vec TA2_missingoutcome, addto(TA2_missingoutcome) name(col2); 

* mean; 
ereplace outcome = mean(cocainefull1miss) if e(sample);

* r squared; 
replace r2 = e(r2) if e(sample);
estpost su outcome r2 if e(sample);
est store B ;

*** heroin; 
reg heruse1miss targetgrp lcd4imp lcd4t raceaa racehisp raceother ageatvis agesq i.site, cluster(wihsid);
est2vec TA2_missingoutcome, addto(TA2_missingoutcome) name(col3); 

* mean; 
ereplace outcome = mean(heruse1miss) if e(sample);

* r squared; 
replace r2 = e(r2) if e(sample);
estpost su outcome r2 if e(sample);
est store C;


*** employment; 
reg employ1miss targetgrp lcd4imp lcd4t raceaa racehisp raceother ageatvis agesq i.site, cluster(wihsid);
est2vec TA2_missingoutcome, addto(TA2_missingoutcome) name(col4); 

* mean; 
ereplace outcome = mean(employ1miss) if e(sample);

* r squared; 
replace r2 = e(r2) if e(sample);
estpost su outcome r2 if e(sample);
est store D;


*** income; 
reg inc1miss targetgrp lcd4imp lcd4t raceaa racehisp raceother ageatvis agesq i.site, cluster(wihsid); 
est2vec TA2_missingoutcome, addto(TA2_missingoutcome) name(col5); 

* mean ; 
ereplace outcome = mean(inc1miss) if e(sample);

* r squared; 
replace r2 = e(r2) if e(sample);
estpost su outcome r2 if e(sample);
est store E;


*** create tables; 
est2texOWO TA2_missingoutcome, collabels(1 2 3 4 5) mark(starb) label dots notabular path($tabledir/appendix) levels(90 95 99) fancy preserve replace;

esttab A B C D E using "$tabledir\appendix\TA2_missingoutcomestats.tex", replace label cells(mean(fmt(3)));
};


**** Table: Heterogeneity in Effects of HAART on Domestic Violence (A-3); 
if `TA3' ==1 {; 
*** Call data;
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;


*** Define controls; 
local control0 ageatvis agesq agecube racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/;

keep if (targetsamp ==1 | healthysamp==1);

* gen AA * target * salient; 
gen targetgrpHAA = raceaa*targetgrpH;
label var targetgrpHAA "Treatment $\times$ AA $\times$ HAART";
gen HAARTavailableAA = raceaa*HAARTavailable;
label var HAARTavailableAA "AA $\times$ HAART";
gen targetgrpAA = raceaa*targetgrp;
label var targetgrpAA "Treatment $\times$ AA";

*** no controls; 
probit dva1 HAARTavailable targetgrp raceaa targetgrpH HAARTavailableAA targetgrpAA targetgrpHAA, cluster(wihsid);
est2vec TA3_heterogeneity, replace vars(HAARTavailable targetgrp raceaa targetgrpH HAARTavailableAA targetgrpAA targetgrpHAA) ;

* mean; 
egen outcome = mean(dva1) if e(sample);
label var outcome "Mean";

* r squared; 
gen r2 = e(r2_p) if e(sample);
label var r2 "Pseudo \$R^{2}\$";

estpost su outcome r2 if e(sample);
est store A;

*** with controls; 
probit dva1 HAARTavailable targetgrp raceaa targetgrpH HAARTavailableAA targetgrpAA targetgrpHAA `control0', cluster(wihsid);
est2vec TA3_heterogeneity, name(col2) addto(TA3_heterogeneity);

* mean; 
ereplace outcome = mean(dva1) if e(sample);

* r squared; 
replace r2 = e(r2_p) if e(sample);

estpost su outcome r2 if e(sample);
est store B;

*** Create table; 
est2texOWO TA3_heterogeneity, collabels(1 2) mark(starb) label dots notabular path($tabledir/appendix) levels(90 95 99) fancy preserve replace;

esttab A B using "$tabledir/appendix/TA3_heterogeneitystats.tex", replace label cells(mean(fmt(3)));
}; 


**** Table: Marginal Effects of Women who Did not Die w/i 7.5 Years of Study (A-4); 
if `TA4'==1 {; 
*** call the data; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;
keep if (death==0 | maxvisdeath>=15) ;

local controlTA4 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/;
* for AA only, leave out race;
local controlTA4race ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/;


***** Violence; 
*** generate sample; 
probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if (targetsamp==1 | healthysamp==1);
gen sampdv = e(sample);

*** no controls; 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH if sampdv==1, cluster(wihsid);

* mean; 
egen outcome = mean(dva1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
label var outcome "Pre-HAART treatment group mean";

egen outcomeall = mean(dva1) if e(sample);
label var outcomeall "Mean";

* r squared; 
gen r2_p = e(r2_p) if e(sample);
label var r2_p "Pseudo \$R^{2}\$";

* margins; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store A;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store A2; 

*** with controls; 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if sampdv==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(dva1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(dva1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store B;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store B2; 


***** Cocaine; 
*** generate sample; 
probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1;
gen sampcoc = e(sample);

*** no controls; 
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH if sampcoc==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(cocainefull1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(cocainefull1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store C;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store C2; 

*** with controls; 
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if sampcoc==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(cocainefull1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(cocainefull1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store D;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store D2; 


***** Heroin use; 
*** generate sample; 
probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1;
gen sampher = e(sample);

*** no controls; 
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH if sampher==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(heruse1) if sampher==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(heruse1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store E;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store E2; 


*** with controls; 
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4' if sampher==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(heruse1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(heruse1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store F;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store F2; 


esttab A B C D E F using "$tabledir\appendix\TA4_notdead.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3))) star(* 0.10 ** 0.05 *** .01);
esttab A2 B2 C2 D2 E2 F2 using "$tabledir\appendix\TA4_notdeadstats.tex", replace label cells(mean(fmt(3)));



******* Black women; 
est clear;
keep if raceaa==1;

***** Violence; 
*** generate sample; 
probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if (targetsamp==1 | healthysamp==1);
gen sampdvaa = e(sample);

*** no controls; 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH if sampdvaa==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(dva1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(dva1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* margins; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store A;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store A2; 


*** with controls; 
xi: probit dva1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if sampdvaa==1, cluster(wihsid); 

* mean; 
ereplace outcome = mean(dva1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(dva1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* margins; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store B;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store B2; 



***** Cocaine; 
*** generate sample; 
probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1;
gen sampcocaa = e(sample);


*** no controls; 
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH if sampcocaa==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(cocainefull1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(cocainefull1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store C;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store C2; 

*** with controls; 
xi: probit cocainefull1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if sampcocaa==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(cocainefull1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(cocainefull1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store D;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store D2; 


**** Heroin use; 
*** generate sample; 
probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1;
gen sampheraa = e(sample);

*** no controls; 
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH if sampheraa==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(heruse1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(heruse1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store E;

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store E2; 


*** with controls; 
xi: probit heruse1 i.HAARTavailable i.targetgrp i.targetgrpH `controlTA4race' if sampheraa==1, cluster(wihsid);

* mean; 
ereplace outcome = mean(heruse1) if e(sample)==1 & HAARTavailable==0 & targetsamp==1;
ereplace outcomeall = mean(heruse1) if e(sample);

* r squared; 
replace r2_p = e(r2_p) if e(sample);

* marginals; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post;
est store F; 

* save extra stats; 
estpost su outcome outcomeall r2_p if e(sample);
est store F2; 

esttab A B C D E F using "$tabledir\appendix\TA4_notdead_black.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3))) star(* 0.10 ** 0.05 *** .01);
esttab A2 B2 C2 D2 E2 F2 using "$tabledir\appendix\TA4_notdeadstats_black.tex", replace label cells(mean(fmt(3)));

};



**** Table: Normalized Differences (A-5); 
if `TA5' ==1 {;  
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

** since only looking at pre-HAART outcomes, keep one obs per individual; 
bys wihsid: gen nvals=(_n==1); 
keep if nvals==1; 

egen Nt = sum(targetsamp);
egen Nc1 = sum(negsamp);
egen Nc2 = sum(healthysamp); 

egen Ntaa = sum(targetsamp==1 & raceaa==1); 
egen Nc1aa = sum(negsamp==1 & raceaa==1); 
egen Nc2aa = sum(healthysamp==1 & raceaa==1); 

local predetv raceaa racehisp raceother racewhite maxincpreH maxincpreH1 
maxincpreH2 maxincpreH3 maxincpreH4 maxincpreH5 maxincpreH6 ageatvis sitebronx
sitebrooklyn sitedc sitela /*sitesanfran*/ lths hsgrad collegegrad somecollege 
marriedpreH kidsbl smokecrntpreH
dvapreH cocainefullpreH herusepreH employpreH drink cursmoke hivpostime; 

foreach var in `predetv' {; 

egen mu`var't0 = mean(`var') if targetsamp==1; 
egen mu`var't = max(mu`var't0);
drop mu`var't0; 

egen mu`var'c0 = mean(`var') if negsamp ==1; 
egen mu`var'c1 = max(mu`var'c0);
drop mu`var'c0; 

egen mu`var'c0 = mean(`var') if healthysamp==1; 
egen mu`var'c2 = max(mu`var'c0); 
drop mu`var'c0; 


gen St`var'_i = (`var' - mu`var't)*(`var'-mu`var't) if targetsamp==1;
gen Sc1`var'_i = (`var' - mu`var'c1)*(`var'-mu`var'c1) if negsamp==1;
gen Sc2`var'_i = (`var' - mu`var'c2)*(`var'-mu`var'c2) if healthysamp==1; 

egen St`var'_sum = total(St`var'_i); 
egen Sc1`var'_sum = total(Sc1`var'_i); 
egen Sc2`var'_sum = total(Sc2`var'_i);

gen St`var' = 1/(Nt-1) * St`var'_sum;
gen Sc1`var' = 1/(Nc1-1) * Sc1`var'_sum; 
gen Sc2`var' = 1/(Nc2-1) * Sc2`var'_sum; 


gen D_`var' = .; 
replace D_`var' = (mu`var't - mu`var'c1)/sqrt(St`var'/2 + Sc1`var'/2) if negsamp==1; 
replace D_`var' = (mu`var't - mu`var'c2)/sqrt(St`var'/2 + Sc2`var'/2) if healthysamp==1; 

}; 

** Label to make table easier to make; 
label var D_raceaa "African American";
label var D_racehisp "Hispanic";
label var D_raceother "Other race";
label var D_racewhite "White";
label var D_maxincpreH "Max income pre-HAART"; 
label var D_maxincpreH1 "Max inc pre-HAART $<$ 6000"; 
label var D_maxincpreH2 "Max inc pre-HAART 6001-12000";               
label var D_maxincpreH3 "Max inc pre-HAART 12001-18000";              
label var D_maxincpreH4 "Max inc pre-HAART 18001-24000";             
label var D_maxincpreH5 "Max inc pre-HAART 24001-30000";              
label var D_maxincpreH6 "Max inc pre-HAART $>$ 30000" ;
label var D_marriedpreH "Married pre-HAART"; 
label var D_kidsbl "Lived with kids at baseline"; 
label var D_ageatvis "Age at visit";
label var D_sitebronx "Bronx";
label var D_sitebrooklyn "Brooklyn";
label var D_sitedc "DC";
label var D_sitela "LA";
label var D_lths "Less than HS"; 
label var D_hsgrad "HS graduate"; 
label var D_somecollege "Some college"; 
label var D_collegegrad "College graduate";
label var D_dvapreH "Experienced DV pre-HAART";
label var D_cocainefullpreH "Cocaine use pre-HAART";
label var D_herusepreH "Heroin use pre-HAART";
label var D_employpreH "Employed pre-HAART"; 
label var D_cursmoke "Smokes"; 
label var D_drink "Drinks"; 
label var D_hivpostime "Time since 1$^{st}$ $+$ HIV test"; 


local Dvars D_raceaa D_racehisp D_racewhite D_raceother D_maxincpreH D_maxincpreH1
D_maxincpreH2 D_maxincpreH3 D_maxincpreH4 D_maxincpreH5 D_maxincpreH6 
D_ageatvis D_sitebronx D_sitebrooklyn D_sitedc D_sitela 
D_lths D_hsgrad D_somecollege D_collegegrad D_marriedpreH D_kidsbl 
D_dvapreH D_cocainefullpreH D_herusepreH D_employpreH D_cursmoke D_drink 
D_hivpostime ; 

estpost su `Dvars' if healthysamp==1; 
est store A ;


esttab A using "$tabledir\appendix\TA5_normalizeddiff.tex", replace label cells(mean(fmt(2))) mtitle("HIV+, Healthy Sample" "HIV $-$ Sample");
};



**** Table: Propensity Score (A-6); 
if `TA6' ==1 {; 

***** DOMESTIC VIOLENCE;  
* Define controls ;
local dvhealthylin ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ dvapreH hivpostime hsgrad 
collegegrad kidsbl;

local dvhealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ dvapreH hivpostime hsgrad collegegrad kidsbl; 

local dvhealthy ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/ dvapreH hivpostime hsgrad 
collegegrad kidsbl c.ageatvis#i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##c.hivpostime c.ageatvis##collegegrad c.ageatvis##kidsbl 
c.ageatvis##i.dvapreH i.raceaa##i.hsgrad i.raceaa##i.kidsbl i.racehisp##i.hsgrad
i.racehisp##i.collegegrad i.hsgrad##c.hivpostime i.collegegrad##i.dvapreH
c.hivpostime##i.kidsbl i.dvapreH##i.kidsbl i.racehisp##i.kidsbl 
i.racehisp##i.dvapreH c.hivpostime##i.dvapreH;

local dvhealthyaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc /*sitela 
sitesanfran sitechicago*/ dvapreH hivpostime hsgrad collegegrad kidsbl 
c.ageatvis##c.hivpostime c.ageatvis##collegegrad c.ageatvis##kidsbl 
c.ageatvis##i.dvapreH i.hsgrad##c.hivpostime i.collegegrad##i.dvapreH
c.hivpostime##i.kidsbl i.dvapreH##i.kidsbl c.hivpostime##i.dvapreH;


*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 


set scheme s1mono; 

** full sample; 
teffects ipw (dva) (targetgrp `dvhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (dva) (targetgrp `dvhealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects overlap, legend(label(1 "HIV+ High CD4") label(2 "Treatment Group")) xtitle("Propensity Score");
graph export "$startdir/Estimation/Stata/Dofiles/Gwyn/final/output/figures/FA2_dvlin.pdf", replace; 

teffects ipw (dva) (targetgrp `dvhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (dva) (targetgrp `dvhealthy', logit) if flag2!=1, vce(robust); 
est store B; 

*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (dva) (targetgrp `dvhealthylinaa', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (dva) (targetgrp `dvhealthylinaa', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (dva) (targetgrp `dvhealthyaa', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (dva) (targetgrp `dvhealthyaa', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensitydv.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Full Samp: Lin" "Full Samp: Quad" "AA Samp: Lin" "AA Samp: Quad");
 

***** HEROINE USE; 
local herhealthylin ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ herusepreH hsgrad 
collegegrad kidsbl ; 

local herhealthy ageatvis agesq agecube raceaa racehisp /*raceother*/ sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ herusepreH hsgrad 
collegegrad kidsbl hivpostime c.ageatvis##i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##i.herusepreH c.ageatvis##i.kidsbl c.ageatvis##c.hivpostime 
i.raceaa##i.hsgrad i.raceaa##i.kidsbl i.racehisp##i.hsgrad 
i.racehisp##c.hivpostime i.herusepreH##i.kidsbl i.herusepreH##c.hivpostime 
i.hsgrad##c.hivpostime i.kidsbl##c.hivpostime i.raceaa##c.hivpostime 
i.racehisp##i.kidsbl; 

local herhealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc 
sitela /*sitesanfran sitechicago*/ herusepreH hsgrad collegegrad kidsbl ; 

local herhealthyaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ herusepreH hsgrad collegegrad kidsbl 
hivpostime c.ageatvis##i.herusepreH c.ageatvis##i.kidsbl c.ageatvis##c.hivpostime 
i.herusepreH##i.kidsbl i.herusepreH##c.hivpostime 
i.hsgrad##c.hivpostime i.kidsbl##c.hivpostime ;


*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 

teffects ipw (heruse) (targetgrp `herhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (heruse) (targetgrp `herhealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects ipw (heruse) (targetgrp `herhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (heruse) (targetgrp `herhealthy', logit) if flag2!=1, vce(robust); 
est store B; 


*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (heruse) (targetgrp `herhealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (heruse) (targetgrp `herhealthylin', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (heruse) (targetgrp `herhealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (heruse) (targetgrp `herhealthy', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensityheroin.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Linear" "Quadratic" "Linear" "Quadratic");

 

***** COCAINE USE; 
local cochealthylin ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime 
hsgrad collegegrad kidsbl; 

local cochealthy ageatvis agesq agecube raceaa racehisp raceother sitebronx 
sitebrooklyn sitedc sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime 
hsgrad collegegrad kidsbl c.ageatvis##i.raceaa c.ageatvis##i.racehisp 
c.ageatvis##i.cocainefullpreH c.ageatvis##c.hivpostime c.ageatvis##i.kidsbl 
i.raceaa##i.hsgrad i.racehisp##i.cocainefullpreH i.racehisp##i.hsgrad 
i.cocainefullpreH##c.hivpostime i.cocainefullpreH##i.kidsbl 
c.ageatvis##i.collegegrad i.raceaa##i.kidsbl; 

local cochealthylinaa ageatvis agesq agecube sitebronx sitebrooklyn sitedc 
sitela /*sitesanfran sitechicago*/ cocainefullpreH hivpostime hsgrad collegegrad 
kidsbl; 

local cochealthy ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela 
/*sitesanfran sitechicago*/ cocainefullpreH hivpostime hsgrad collegegrad kidsbl 
c.ageatvis##i.cocainefullpreH c.ageatvis##c.hivpostime c.ageatvis##i.kidsbl 
i.cocainefullpreH##c.hivpostime i.cocainefullpreH##i.kidsbl 
c.ageatvis##i.collegegrad ; 

*** PRE-HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==0; 

teffects ipw (cocainefull) (targetgrp `cochealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (cocainefull) (targetgrp `cochealthylin', logit) if flag!=1, vce(robust); 
est store A; 

teffects ipw (cocainefull) (targetgrp `cochealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (cocainefull) (targetgrp `cochealthy', logit) if flag2!=1, vce(robust); 
est store B; 


*** POST HAART; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if healthysamp==1 | targetsamp==1;
keep if HAARTavailable==1; 

teffects ipw (cocainefull) (targetgrp `cochealthylin', logit), vce(robust);
predict ps1, ps;  
gen flag = ps1 <.1 | ps1>.9;
teffects ipw (cocainefull) (targetgrp `cochealthylin', logit) if flag!=1, vce(robust); 
est store C; 

teffects ipw (cocainefull) (targetgrp `cochealthy', logit), vce(robust);
predict ps11, ps;  
gen flag2 = ps11 <.1 | ps11>.9;
teffects ipw (cocainefull) (targetgrp `cochealthy', logit) if flag2!=1, vce(robust); 
est store D; 

esttab A B C D using "$tabledir\appendix\TA6_propensitycoc.tex",
 replace label cells(b(star fmt(4)) se(par fmt(4))) star(* .1 ** .05 *** .01)
 mtitle("Linear" "Quadratic" "Linear" "Quadratic");
};


****** Table A7 & A8: Joint Estimation; 
if `TA7A8' ==1 {; 

*** Define controls; 
local controlTA7TA8 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/;

* for AA only, leave out race;
local controlTA7TA8race ageatvis agesq agecube sitebronx sitebrooklyn sitedc /*sitela sitesanfran sitechicago*/;

 
 
****** Cocaine & Violence; 
*** call the data; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if (targetsamp ==1 | healthysamp==1);

** Get resutls from dva regression; 
biprobit (dva1 HAARTavailable targetgrp targetgrpH)(cocainefull1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA7_dvcoc, vars(HAARTavailable targetgrp targetgrpH) replace;
local rho0 = e(rho);
gen rho0 = `rho0';
egen outcomedv0 = mean(dva1) if e(sample);
egen outcomecoc0 = mean(cocainefull1) if e(sample);

biprobit (dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8')(cocainefull1 HAARTavailable targetgrp targetgrpH `controlTA7TA8'), cluster(wihsid);
est2vec TA7_dvcoc, name(col2) addto(TA7_dvcoc);
local rho1 = e(rho);
gen rho1 = `rho1';
egen outcomedv1 = mean(dva1) if e(sample);
egen outcomecoc1 = mean(cocainefull1) if e(sample);

** Get resutls from cocaine regression; 
biprobit (cocainefull1 HAARTavailable targetgrp targetgrpH)(dva1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA7_cocaine, vars(HAARTavailable targetgrp targetgrpH) replace;

biprobit (cocainefull1 HAARTavailable targetgrp targetgrpH `controlTA7TA8')(dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8'), cluster(wihsid);
est2vec TA7_cocaine, name(col2) addto(TA7_cocaine);


est2texOWO TA7_dvcoc, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;
est2texOWO TA7_cocaine, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;

keep rho* outcome*;

collapse (mean) rho* outcome*;

set obs 3;
gen column1 = "";
replace column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Cocaine Use" if _n==2;
replace column1 = "Rho" if _n==3;

gen column2 = "&";

gen column3 = outcomedv0[1] if _n==1;
replace column3 = outcomecoc0[1] if _n==2;
replace column3 = rho0[1] if _n==3;

gen column4 = "&";

gen column5 = outcomedv1[1] if _n==1;
replace column5 = outcomecoc1[1] if _n==2;
replace column5 = rho1[1] if _n==3;

gen column6 = "\\";

keep column*;
format column3 column5 %9.3f ;
save $tabledir\appendix\TA7_rhodvcoc.dta, replace;


**** African Americans only ;
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if (targetsamp ==1 | healthysamp==1) & raceaa==1;

*** First, get results from the dv regression; 
biprobit (dva1 HAARTavailable targetgrp targetgrpH)(cocainefull1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA7_dvcocaa, vars(HAARTavailable targetgrp targetgrpH) replace;
local rho0 = e(rho);
gen rho0 = `rho0';
egen outcomedv0 = mean(dva1) if e(sample);
egen outcomecoc0 = mean(cocainefull1) if e(sample);

biprobit (dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race')(cocainefull1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race'), cluster(wihsid);
est2vec TA7_dvcocaa, name(col2) addto(TA7_dvcocaa);
local rho1 = e(rho);
gen rho1 = `rho1';
egen outcomedv1 = mean(dva1) if e(sample);
egen outcomecoc1 = mean(cocainefull1) if e(sample);

*** Second, get results from the stimulant regression; 
biprobit (cocainefull1 HAARTavailable targetgrp targetgrpH)(dva1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA7_cocaineaa, vars(HAARTavailable targetgrp targetgrpH) replace;

biprobit (cocainefull1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race')(dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race'), cluster(wihsid);
est2vec TA7_cocaineaa, name(col2) addto(TA7_cocaineaa);

est2texOWO TA7_dvcocaa, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;
est2texOWO TA7_cocaineaa, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;

keep rho* outcome*;

collapse (mean) rho* outcome*;

set obs 3;
gen column1 = "";
replace column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Cocaine Use" if _n==2;
replace column1 = "Rho" if _n==3;

gen column2 = "&";

gen column3 = outcomedv0[1] if _n==1;
replace column3 = outcomecoc0[1] if _n==2;
replace column3 = rho0[1] if _n==3;

gen column4 = "&";

gen column5 = outcomedv1[1] if _n==1;
replace column5 = outcomecoc1[1] if _n==2;
replace column5 = rho1[1] if _n==3;

gen column6 = "\\";

keep column*;
format column3 column5 %9.3f ;
save $tabledir\appendix\TA7_rhodvcocaa.dta, replace;



****** Heroin & Violence; 
*** call the data; 
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
xtset wihsid visit;

keep if (targetsamp ==1 | healthysamp==1);

** Get resutls from dva regression; 
biprobit (dva1 HAARTavailable targetgrp targetgrpH)(heruse1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA8_dvher, vars(HAARTavailable targetgrp targetgrpH) replace;
local rho0 = e(rho);
gen rho0 = `rho0';
egen outcomedv0 = mean(dva1) if e(sample);
egen outcomeher0 = mean(heruse1) if e(sample);

biprobit (dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8')(heruse1 HAARTavailable targetgrp targetgrpH `controlTA7TA8'), cluster(wihsid);
est2vec TA8_dvher, name(col2) addto(TA8_dvher);
local rho1 = e(rho);
gen rho1 = `rho1';
egen outcomedv1 = mean(dva1) if e(sample);
egen outcomeher1 = mean(heruse1) if e(sample);

** Get resutls from heroin use regression; 
biprobit (heruse1 HAARTavailable targetgrp targetgrpH)(dva1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA8_her, vars(HAARTavailable targetgrp targetgrpH) replace;

biprobit (heruse1 HAARTavailable targetgrp targetgrpH `controlTA7TA8')(dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8'), cluster(wihsid);
est2vec TA8_her, name(col2) addto(TA8_her);


est2texOWO TA8_dvher, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;
est2texOWO TA8_her, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;

keep rho* outcome*;

collapse (mean) rho* outcome*;

set obs 3;
gen column1 = "";
replace column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Heroin Use" if _n==2;
replace column1 = "Rho" if _n==3;

gen column2 = "&";

gen column3 = outcomedv0[1] if _n==1;
replace column3 = outcomeher0[1] if _n==2;
replace column3 = rho0[1] if _n==3;

gen column4 = "&";

gen column5 = outcomedv1[1] if _n==1;
replace column5 = outcomeher1[1] if _n==2;
replace column5 = rho1[1] if _n==3;

gen column6 = "\\";

keep column*;
format column3 column5 %9.3f e column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Heroin Use" if _n==2;
replace column1 = "Rho" if _n==3;

save $tabledir\appendix\TA8_rhodvher.dta, replace;




**** African Americans only ;
use "$startdir\Estimation\Stata\Dofiles\Gwyn\final\wihs_clean_dv.dta", clear;
keep if (targetsamp ==1 | healthysamp==1) & raceaa==1;

*** First, get results from the dva regression; 
biprobit (dva1 HAARTavailable targetgrp targetgrpH)(heruse1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA8_dvheraa, vars(HAARTavailable targetgrp targetgrpH) replace;
local rho0 = e(rho);
gen rho0 = `rho0';
egen outcomedv0 = mean(dva1) if e(sample);
egen outcomeher0 = mean(heruse1) if e(sample);

biprobit (dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race')(heruse1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race'), cluster(wihsid);
est2vec TA8_dvheraa, name(col2) addto(TA8_dvheraa);
local rho1 = e(rho);
gen rho1 = `rho1';
egen outcomedv1 = mean(dva1) if e(sample);
egen outcomeher1 = mean(heruse1) if e(sample);

*** Second, get results from the heroin regression; 
biprobit (heruse1 HAARTavailable targetgrp targetgrpH)(dva1 HAARTavailable targetgrp targetgrpH), cluster(wihsid);
est2vec TA8_heraa, vars(HAARTavailable targetgrp targetgrpH) replace;

biprobit (heruse1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race')(dva1 HAARTavailable targetgrp targetgrpH `controlTA7TA8race'), cluster(wihsid);
est2vec TA8_heraa, name(col2) addto(TA8_heraa);

est2texOWO TA8_dvheraa, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;
est2texOWO TA8_heraa, collabels(1 2) mark(starb) label dots notabular path($tabledir\appendix) levels(90 95 99) fancy preserve replace;


keep rho* outcome*;
collapse (mean) rho* outcome*;
set obs 3;
gen column1 = "";
replace column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Heroin Use" if _n==2;
replace column1 = "Rho" if _n==3;

gen column2 = "&";

gen column3 = outcomedv0[1] if _n==1;
replace column3 = outcomeher0[1] if _n==2;
replace column3 = rho0[1] if _n==3;

gen column4 = "&";

gen column5 = outcomedv1[1] if _n==1;
replace column5 = outcomeher1[1] if _n==2;
replace column5 = rho1[1] if _n==3;

gen column6 = "\\";

keep column*;
format column3 column5 %9.3f e column1 = "Mean Domestic Violence" if _n==1;
replace column1 = "Mean Heroin Use" if _n==2;
replace column1 = "Rho" if _n==3;

save $tabledir\appendix\TA8_rhodvheraa.dta, replace;

}; 
